@@ -1,13 +1,30 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4; tab-width: 8 -*- */
-/**
+/*
  * gdl-dock-item-grip.c
  *
- * Based on bonobo-dock-item-grip.  Original copyright notice follows.
+ * Author: Michael Meeks Copyright (C) 2002 Sun Microsystems, Inc.
  *
- * Author:
- *    Michael Meeks
+ * Based on BonoboDockItemGrip.  Original copyright notice follows.
  *
- * Copyright (C) 2002 Sun Microsystems, Inc.
+ * Copyright (C) 1998 Ettore Perazzoli
+ * Copyright (C) 1998 Elliot Lee
+ * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald 
+ * All rights reserved.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -329,9 +346,14 @@ gdl_dock_item_grip_realize (GtkWidget *widget)
                                              &attributes, (GDK_WA_X | GDK_WA_Y));
 
         gdk_window_set_user_data (grip->title_window, grip);
-        widget->window = grip->title_window;
+
+        /* Unref the ref from parent realize for NO_WINDOW */
+        g_object_unref (widget->window);
+
+        /* Need to ref widget->window, because parent unrealize unrefs it */
+        widget->window = g_object_ref (grip->title_window);
         GTK_WIDGET_UNSET_FLAGS(widget, GTK_NO_WINDOW);
-        
+
         /* Unset the background so as to make the colour match the parent window */
         gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, NULL);
  
