@@ -17,6 +17,10 @@ GType gdl_dock_object_flags_get_type (void);
 #define GDL_TYPE_DOCK_PLACEMENT gdl_dock_placement_get_type()
 GType gdl_dock_placement_get_type (void);
 
+/* --- gdl-dock-master.h --- */
+#define GDL_TYPE_SWITCHER_STYLE gdl_switcher_style_get_type()
+GType gdl_switcher_style_get_type (void);
+
 /* --- gdl-dock-item.h --- */
 #define GDL_TYPE_DOCK_ITEM_BEHAVIOR gdl_dock_item_behavior_get_type()
 GType gdl_dock_item_behavior_get_type (void);
